# Getting Started

## Open and Save Files

Press `Ctrl+N` and you will see a command palette pops up. This palette contains many
commands that are related to adding new items to the application. For example, the
"New Text" command will add a new text editor sub-window to the current tab.


## The Plugin System

In `himena`, all the functionalities including opening, saving and processing data are
provided by plugins. `himena` has a built-in plugin named `himena-builtins` that already
provides many readers, writers, widgets and tools.

`Ctrl+,`

![](../images/02_chart_io.png)

## The Python Interpreter Console
